import Layout from '@/layout'
import { h, resolveComponent } from 'vue'

const ActualTimeRoutes = {
  path: '/realTime',
  component: Layout,
  name: 'realTime',
  redirect: '/realTime/departure',
  //using el svg icon, the elSvgIcon first when at the same time using elSvgIcon and icon
  meta: { title: '综合可视化', elSvgIcon: 'Fold', breadcrumb: false },
  children: [
    {
      path: '/realTime/departure',
      name: 'Departure',
      redirect: '/realTime/departure/station',
      meta: {
        title: '国内出港',
        elSvgIcon: 'Fold',
        icon: 'table',
      },
      component: {
        render: () => h(resolveComponent('router-view')),
      },
      children: [
        {
          path: '/realTime/departure/station',
          name: 'DepartureStation',
          meta: {
            title: '国内出港航站视图',
            elSvgIcon: 'Fold',
            icon: 'table',
            breadcrumb: false,
          },
          component: {
            render: () => h(resolveComponent('router-view')),
          },
          children: [
            {
              path: '/realTime/departure/station',
              name: 'DepartureStationView',
              component: () =>
                import('@/views/realTime/departure/station/index.vue'),
            },
            {
              path: '/realTime/departure/flight',
              name: 'DepartureFlight',
              meta: {
                title: '国内出港航班视图',
                elSvgIcon: 'Fold',
                icon: 'table',
              },
              component: {
                render: () => h(resolveComponent('router-view')),
              },
              children: [
                {
                  path: '/realTime/departure/flight',
                  name: 'DepartureFlightView',
                  component: () =>
                    import('@/views/realTime/departure/flight/index.vue'),
                },
                {
                  path: '/realTime/departure/waybill',
                  name: 'DepartureWaybill',
                  meta: {
                    title: '国内出港运单视图',
                    elSvgIcon: 'Fold',
                    icon: 'table',
                  },
                  component: {
                    render: () => h(resolveComponent('router-view')),
                  },
                  children: [
                    {
                      path: '/realTime/departure/waybill',
                      name: 'DepartureWaybillView',
                      component: () =>
                        import(
                          '@/views/realTime/departure/waybill/index.vue'
                        ),
                    },
                    {
                      path: '/realTime/departure/goods',
                      name: 'DepartureGoods',
                      meta: {
                        title: '国内出港货物视图',
                        elSvgIcon: 'Fold',
                        icon: 'table',
                      },
                      component: () =>
                        import('@/views/realTime/departure/goods/index.vue'),
                    },
                  ],
                },
              ],
            },
          ],
        },
      ],
    },
    {
      path: '/realTime/internationalDeparture',
      name: 'InternationalDeparture',
      redirect: '/realTime/internationalDeparture/station',
      meta: {
        title: '国际出港',
        elSvgIcon: 'Fold',
        icon: 'table',
        breadcrumb: false,
      },
      component: {
        render: () => h(resolveComponent('router-view')),
      },
      children: [
        {
          path: '/realTime/internationalDeparture/station',
          name: 'InternationalDepartureStation',
          meta: { title: '国际出港航站视图', elSvgIcon: 'Fold', icon: 'table' },
          component: {
            render: () => h(resolveComponent('router-view')),
          },
          children: [
            {
              path: '/realTime/internationalDeparture/station',
              name: 'InternationalDepartureStationView',
              component: () =>
                import(
                  '@/views/realTime/internationalDeparture/station/index.vue'
                ),
            },
            {
              path: '/realTime/internationalDeparture/flight',
              name: 'InternationalDepartureFlight',
              meta: {
                title: '国际出港航班视图',
                elSvgIcon: 'Fold',
                icon: 'table',
              },
              component: {
                render: () => h(resolveComponent('router-view')),
              },
              children: [
                {
                  path: '/realTime/internationalDeparture/flight',
                  name: 'InternationalDepartureFlightView',
                  component: () =>
                    import(
                      '@/views/realTime/internationalDeparture/flight/index.vue'
                    ),
                },
                {
                  path: '/realTime/internationalDeparture/waybill',
                  name: 'InternationalDepartureWaybill',
                  meta: {
                    title: '国际出港运单视图',
                    elSvgIcon: 'Fold',
                    icon: 'table',
                  },
                  component: {
                    render: () => h(resolveComponent('router-view')),
                  },
                  children: [
                    {
                      path: '/realTime/internationalDeparture/waybill',
                      name: 'InternationalDepartureWaybillView',
                      component: () =>
                        import(
                          '@/views/realTime/internationalDeparture/waybill/index.vue'
                        ),
                    },
                    {
                      path: '/realTime/internationalDeparture/goods',
                      name: 'InternationalDepartureGoods',
                      meta: {
                        title: '国际出港货物视图',
                        elSvgIcon: 'Fold',
                        icon: 'table',
                      },
                      component: () =>
                        import(
                          '@/views/realTime/internationalDeparture/goods/index.vue'
                        ),
                    },
                  ],
                },
              ],
            },
          ],
        },
      ],
    },
    {
      path: '/realTime/arrival',
      name: 'Arrival',
      redirect: '/realTime/arrival/station',
      meta: {
        title: '国内进港',
        elSvgIcon: 'Fold',
        icon: 'table',
        breadcrumb: false,
      },
      component: {
        render: () => h(resolveComponent('router-view')),
      },
      children: [
        {
          path: '/realTime/arrival/station',
          name: 'ArrivalStation',
          meta: { title: '国内进港航站视图', elSvgIcon: 'Fold', icon: 'table' },
          component: {
            render: () => h(resolveComponent('router-view')),
          },
          children: [
            {
              path: '/realTime/arrival/station',
              name: 'ArrivalStationView',
              component: () =>
                import('@/views/realTime/arrival/station/index.vue'),
            },
            {
              path: '/realTime/arrival/flight',
              name: 'ArrivalFlight',
              meta: {
                title: '国内进港航班视图',
                elSvgIcon: 'Fold',
                icon: 'table',
              },
              component: {
                render: () => h(resolveComponent('router-view')),
              },
              children: [
                {
                  path: '/realTime/arrival/flight',
                  name: 'ArrivalFlightView',
                  component: () =>
                    import('@/views/realTime/arrival/flight/index.vue'),
                },
                {
                  path: '/realTime/arrival/waybill',
                  name: 'ArrivalWaybill',
                  meta: {
                    title: '国内进港运单视图',
                    elSvgIcon: 'Fold',
                    icon: 'table',
                  },
                  component: {
                    render: () => h(resolveComponent('router-view')),
                  },
                  children: [
                    {
                      path: '/realTime/arrival/waybill',
                      name: 'ArrivalWaybillView',
                      component: () =>
                        import('@/views/realTime/arrival/waybill/index.vue'),
                    },
                    {
                      path: '/realTime/arrival/goods',
                      name: 'ArrivalGoods',
                      meta: {
                        title: '国内进港货物视图',
                        elSvgIcon: 'Fold',
                        icon: 'table',
                      },
                      component: () =>
                        import('@/views/realTime/arrival/goods/index.vue'),
                    },
                  ],
                },
              ],
            },
          ],
        },
      ],
    },
    {
      path: '/realTime/internationalArrival',
      name: 'InternationalArrival',
      redirect: '/realTime/internationalArrival/station',
      meta: {
        title: '国内进港',
        elSvgIcon: 'Fold',
        icon: 'table',
        breadcrumb: false,
      },
      component: {
        render: () => h(resolveComponent('router-view')),
      },
      children: [
        {
          path: '/realTime/internationalArrival/station',
          name: 'InternationalArrivalStation',
          meta: { title: '国内进港航站视图', elSvgIcon: 'Fold', icon: 'table' },
          component: {
            render: () => h(resolveComponent('router-view')),
          },
          children: [
            {
              path: '/realTime/internationalArrival/station',
              name: 'InternationalArrivalStationView',
              component: () =>
                import(
                  '@/views/realTime/internationalArrival/station/index.vue'
                ),
            },
            {
              path: '/realTime/internationalArrival/flight',
              name: 'InternationalArrivalFlight',
              meta: {
                title: '国内进港航班视图',
                elSvgIcon: 'Fold',
                icon: 'table',
              },
              component: {
                render: () => h(resolveComponent('router-view')),
              },
              children: [
                {
                  path: '/realTime/internationalArrival/flight',
                  name: 'InternationalArrivalFlightView',
                  component: () =>
                    import(
                      '@/views/realTime/internationalArrival/flight/index.vue'
                    ),
                },
                {
                  path: '/realTime/internationalArrival/waybill',
                  name: 'InternationalArrivalWaybill',
                  meta: {
                    title: '国内进港运单视图',
                    elSvgIcon: 'Fold',
                    icon: 'table',
                  },
                  component: {
                    render: () => h(resolveComponent('router-view')),
                  },
                  children: [
                    {
                      path: '/realTime/internationalArrival/waybill',
                      name: 'InternationalArrivalWaybillView',
                      component: () =>
                        import(
                          '@/views/realTime/internationalArrival/waybill/index.vue'
                        ),
                    },
                    {
                      path: '/realTime/internationalArrival/goods',
                      name: 'InternationalArrivalGoods',
                      meta: {
                        title: '国内进港货物视图',
                        elSvgIcon: 'Fold',
                        icon: 'table',
                      },
                      component: () =>
                        import(
                          '@/views/realTime/internationalArrival/goods/index.vue'
                        ),
                    },
                  ],
                },
              ],
            },
          ],
        },
      ],
    },
    {
      path: '/realTime/trackMap',
      name: 'TrackMap',
      meta: { title: '轨迹地图', elSvgIcon: 'Fold', icon: 'table' },
      component: () => import('@/views/realTime/trackMap/index.vue'),
    },
  ],
}

export default [ActualTimeRoutes]
